@@ -1,5 +1,6 @@
 #!/usr/bin/env python
 
+import datetime
 import doctest
 import unittest
 import os.path
@@ -7,6 +8,13 @@ import sys
 import time
 from glob import glob
 
+class FakeDatetime(datetime.datetime):
+    @classmethod
+    def utcnow(cls):
+        return cls(2015, 12, 14, 15, 42, 14)
+
+FakeDatetime.__name__ = 'datetime.datetime'
+
 def load_tests(loader, tests, pattern):
 
     # Force time zone to EST/EDT to make localtime tests work.
@@ -18,6 +26,8 @@ def load_tests(loader, tests, pattern):
 
     tests = []
 
+    datetime.datetime = FakeDatetime
+
     if sys.version_info >= (2, 7):
         tests.extend([
             doctest.DocFileSuite('../doc/%s' % os.path.basename(path))
