@@ -1330,16 +1330,14 @@ static PyObject* Body_writedb(PyObject *self)
      return PyUnicode_FromString(line);
 }
 
+void Body__copy_struct(Body *, Body *);
+
 static PyObject* Body_copy(PyObject *self)
 {
      Body *body = (Body *) self;
      Body *newbody = (Body*) self->ob_type->tp_alloc(self->ob_type, 0);
      if (!newbody) return 0;
-     memcpy ((void *)&newbody->now, (void *)&body->now, sizeof(Now));
-     memcpy ((void *)&newbody->obj, (void *)&body->obj, sizeof(Obj));
-     memcpy ((void *)&newbody->riset, (void *)&body->riset, sizeof(RiseSet));
-     newbody->name = body->name;
-     Py_XINCREF(newbody->name);
+     Body__copy_struct(body, newbody);
      return (PyObject*) newbody;
 }
 
@@ -2644,7 +2642,6 @@ static PyObject *build_body_from_obj(PyObject *name, Obj *op)
 	  Py_DECREF(name);
 	  return 0;
      }
-     //body = PyObject_NEW(Body, type);
      body = (Body*) PyType_GenericNew(type, 0, 0);
      if (!body) {
 	  Py_DECREF(name);
@@ -2654,7 +2651,9 @@ static PyObject *build_body_from_obj(PyObject *name, Obj *op)
      if (Set_name((PyObject*) body, name, 0) == -1) {
           Py_DECREF(body);
           Py_DECREF(name);
+          return 0;
      }
+     Py_DECREF(name);
      return (PyObject*) body;
 }
 
@@ -2682,6 +2681,7 @@ static PyObject* readdb(PyObject *self, PyObject *args)
 
 static PyObject* readtle(PyObject *self, PyObject *args)
 {
+     int result;
      char *l0, *l1, *l2;
      PyObject *name, *stripped_name, *body, *catalog_number;
      Obj obj;
@@ -2691,9 +2691,12 @@ static PyObject* readtle(PyObject *self, PyObject *args)
      l0 = PyUnicode_AsUTF8(name);
      if (!l0)
           return 0;
-     if (db_tle(l0, l1, l2, &obj)) {
+     result = db_tle(l0, l1, l2, &obj);
+     if (result) {
 	  PyErr_SetString(PyExc_ValueError,
-			  "line does not conform to tle format");
+			  (result == -2) ?
+                          "incorrect TLE checksum at end of line" :
+                          "line does not conform to tle format");
 	  return 0;
      }
      stripped_name = PyObject_CallMethod(name, "strip", 0);
@@ -3007,6 +3010,46 @@ static PyObject *_next_pass(PyObject *self, PyObject *args)
      }
 }
 
+/*
+ * Why is this all the way down here?  It needs to refer to the type
+ * objects themselves, which are defined rather late in the file.
+ */
+
+void Body__copy_struct(Body *body, Body *newbody)
+{
+     memcpy((void *)&newbody->now, (void *)&body->now, sizeof(Now));
+     memcpy((void *)&newbody->obj, (void *)&body->obj, sizeof(Obj));
+     memcpy((void *)&newbody->riset, (void *)&body->riset, sizeof(RiseSet));
+
+     newbody->name = body->name;
+     Py_XINCREF(newbody->name);
+
+     if (PyObject_IsInstance(body, &MoonType)) {
+          Moon *a = (Moon *) newbody, *b = (Moon *) body;
+          a->llat = b->llat;
+          a->llon = b->llon;
+          a->c = b->c;
+          a->k = b->k;
+          a->s = b->s;
+     }
+     if (PyObject_IsInstance(body, &JupiterType)) {
+          Jupiter *a = (Jupiter *) newbody, *b = (Jupiter *) body;
+          a->cmlI = a->cmlI;
+          a->cmlII = a->cmlII;
+     }
+     if (PyObject_IsInstance(body, &SaturnType)) {
+          Saturn *a = (Saturn *) newbody, *b = (Saturn *) body;
+          a->etilt = a->etilt;
+          a->stilt = a->stilt;
+     }
+     if (PyObject_IsInstance(body, &EarthSatelliteType)) {
+          EarthSatellite *a = (EarthSatellite *) newbody;
+          EarthSatellite *b = (EarthSatellite *) body;
+          a->catalog_number = b->catalog_number;
+          Py_XINCREF(a->name);
+     }
+}
+
 /*
  * The global methods table and the module initialization function.
  */
