@@ -32,6 +32,9 @@
 #include "sattypes.h"
 #include "satlib.h"
 
+#if defined(_MSC_VER) && (_MSC_VER < 1800)
+#define isnan(x) _isnan(x)
+#endif
 
 #define ESAT_MAG        2       /* fake satellite magnitude */
 
@@ -388,14 +391,15 @@ double *SatVX, double *SatVY, double *SatVZ)
 	if (sd.deep)
 	    free (sd.deep);
 
-	/* earth radii to km */
-	*SatX = (ERAD/1000)*posvec.x;	
-	*SatY = (ERAD/1000)*posvec.y;
-	*SatZ = (ERAD/1000)*posvec.z;
-	/* Minutes per day/Seconds by day = Minutes/Second = 1/60 */
-	*SatVX = (ERAD*velvec.x)/(1000*60); 
-	*SatVY =(ERAD*velvec.y)/(1000*60);
-	*SatVZ = (ERAD*velvec.z)/(1000*60);
+ 	/* earth radii to km */
+ 	*SatX = (ERAD/1000)*posvec.x;	
+ 	*SatY = (ERAD/1000)*posvec.y;
+ 	*SatZ = (ERAD/1000)*posvec.z;
+ 	/* Minutes per day/Seconds by day = Minutes/Second = 1/60 */
+ 	*SatVX = (ERAD*velvec.x)/(1000*60); 
+ 	*SatVY =(ERAD*velvec.y)/(1000*60);
+ 	*SatVZ = (ERAD*velvec.z)/(1000*60);
+
 #endif
 }
 
